pub struct UpdateEntityQuery {Show 13 fields
pub id: &'static EntityId,
pub pos: &'static Position,
pub old_pos: &'static OldPosition,
pub loc: &'static EntityLayerId,
pub old_loc: &'static OldEntityLayerId,
pub look: Ref<'static, Look>,
pub head_yaw: Ref<'static, HeadYaw>,
pub on_ground: &'static OnGround,
pub velocity: Ref<'static, Velocity>,
pub tracked_data: &'static TrackedData,
pub statuses: &'static EntityStatuses,
pub animations: &'static EntityAnimations,
pub tracked_attributes: Option<&'static TrackedEntityAttributes>,
}Fields
id: &'static EntityIdpos: &'static Positionold_pos: &'static OldPositionloc: &'static EntityLayerIdold_loc: &'static OldEntityLayerIdlook: Ref<'static, Look>head_yaw: Ref<'static, HeadYaw>on_ground: &'static OnGroundvelocity: Ref<'static, Velocity>tracked_data: &'static TrackedDatastatuses: &'static EntityStatusesanimations: &'static EntityAnimationstracked_attributes: Option<&'static TrackedEntityAttributes>Trait Implementations
Sourceimpl QueryData for UpdateEntityQuery
impl QueryData for UpdateEntityQuery
Sourceunsafe fn fetch<'__w, '__s>(
_state: &'__s Self::State,
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> Option<Self::Item<'__w, '__s>>
unsafe fn fetch<'__w, '__s>( _state: &'__s Self::State, _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> Option<Self::Item<'__w, '__s>>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_READ_ONLY: bool = true
const IS_READ_ONLY: bool = true
True if this query is read-only and may not perform mutable access.
Sourceconst IS_ARCHETYPAL: bool
const IS_ARCHETYPAL: bool
Returns true if (and only if) this query data relies strictly on archetypes to limit which
entities are accessed by the Query. Read more
Sourcetype ReadOnly = UpdateEntityQuery
type ReadOnly = UpdateEntityQuery
The read-only variant of this [
QueryData], which satisfies the [ReadOnlyQueryData] trait.Sourcetype Item<'__w, '__s> = UpdateEntityQueryItem<'__w, '__s>
type Item<'__w, '__s> = UpdateEntityQueryItem<'__w, '__s>
The item returned by this [
WorldQuery]
This will be the data retrieved by the query,
and is visible to the end user when calling e.g. Query<Self>::get.Sourcefn shrink<'__wlong: '__wshort, '__wshort, '__s>(
item: Self::Item<'__wlong, '__s>,
) -> Self::Item<'__wshort, '__s>
fn shrink<'__wlong: '__wshort, '__wshort, '__s>( item: Self::Item<'__wlong, '__s>, ) -> Self::Item<'__wshort, '__s>
This function manually implements subtyping for the query items.
Sourcefn provide_extra_access(
state: &mut Self::State,
access: &mut Access,
available_access: &Access,
)
fn provide_extra_access( state: &mut Self::State, access: &mut Access, available_access: &Access, )
Offers additional access above what we requested in
update_component_access.
Implementations may add additional access that is a subset of available_access
and does not conflict with anything in access,
and must update access to include that access. Read moreSourcefn iter_access(_state: &Self::State) -> impl Iterator<Item = EcsAccessType<'_>>
fn iter_access(_state: &Self::State) -> impl Iterator<Item = EcsAccessType<'_>>
Returns an iterator over the access needed by [
QueryData::fetch]. Access conflicts are usually
checked in [WorldQuery::update_component_access], but in certain cases this method can be useful to implement
a way of checking for access conflicts in a non-allocating way.Sourceimpl ReleaseStateQueryData for UpdateEntityQuerywhere
for<'__a> &'static EntityId: ReleaseStateQueryData,
for<'__a> &'static Position: ReleaseStateQueryData,
for<'__a> &'static OldPosition: ReleaseStateQueryData,
for<'__a> &'static EntityLayerId: ReleaseStateQueryData,
for<'__a> &'static OldEntityLayerId: ReleaseStateQueryData,
for<'__a> Ref<'static, Look>: ReleaseStateQueryData,
for<'__a> Ref<'static, HeadYaw>: ReleaseStateQueryData,
for<'__a> &'static OnGround: ReleaseStateQueryData,
for<'__a> Ref<'static, Velocity>: ReleaseStateQueryData,
for<'__a> &'static TrackedData: ReleaseStateQueryData,
for<'__a> &'static EntityStatuses: ReleaseStateQueryData,
for<'__a> &'static EntityAnimations: ReleaseStateQueryData,
for<'__a> Option<&'static TrackedEntityAttributes>: ReleaseStateQueryData,
impl ReleaseStateQueryData for UpdateEntityQuerywhere
for<'__a> &'static EntityId: ReleaseStateQueryData,
for<'__a> &'static Position: ReleaseStateQueryData,
for<'__a> &'static OldPosition: ReleaseStateQueryData,
for<'__a> &'static EntityLayerId: ReleaseStateQueryData,
for<'__a> &'static OldEntityLayerId: ReleaseStateQueryData,
for<'__a> Ref<'static, Look>: ReleaseStateQueryData,
for<'__a> Ref<'static, HeadYaw>: ReleaseStateQueryData,
for<'__a> &'static OnGround: ReleaseStateQueryData,
for<'__a> Ref<'static, Velocity>: ReleaseStateQueryData,
for<'__a> &'static TrackedData: ReleaseStateQueryData,
for<'__a> &'static EntityStatuses: ReleaseStateQueryData,
for<'__a> &'static EntityAnimations: ReleaseStateQueryData,
for<'__a> Option<&'static TrackedEntityAttributes>: ReleaseStateQueryData,
Sourcefn release_state<'__w>(_item: Self::Item<'__w, '_>) -> Self::Item<'__w, 'static>
fn release_state<'__w>(_item: Self::Item<'__w, '_>) -> Self::Item<'__w, 'static>
Releases the borrow from the query state by converting an item to have a
'static state lifetime.Sourceimpl WorldQuery for UpdateEntityQuery
impl WorldQuery for UpdateEntityQuery
Sourceunsafe fn set_archetype<'__w, '__s>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &'__s Self::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w, '__s>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &'__s Self::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w, '__s>(
_fetch: &mut <Self as WorldQuery>::Fetch<'__w>,
_state: &'__s Self::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w, '__s>( _fetch: &mut <Self as WorldQuery>::Fetch<'__w>, _state: &'__s Self::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceconst IS_DENSE: bool
const IS_DENSE: bool
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. Read more
Sourcetype Fetch<'__w> = UpdateEntityQueryFetch<'__w>
type Fetch<'__w> = UpdateEntityQueryFetch<'__w>
Per archetype/table state retrieved by this [
WorldQuery] to compute Self::Item for each entity.Sourcetype State = UpdateEntityQueryState
type State = UpdateEntityQueryState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink_fetch<'__wlong: '__wshort, '__wshort>(
fetch: <UpdateEntityQuery as WorldQuery>::Fetch<'__wlong>,
) -> <UpdateEntityQuery as WorldQuery>::Fetch<'__wshort>
fn shrink_fetch<'__wlong: '__wshort, '__wshort>( fetch: <UpdateEntityQuery as WorldQuery>::Fetch<'__wlong>, ) -> <UpdateEntityQuery as WorldQuery>::Fetch<'__wshort>
This function manually implements subtyping for the query fetches.
Sourceunsafe fn init_fetch<'__w, '__s>(
_world: UnsafeWorldCell<'__w>,
state: &'__s Self::State,
_last_run: Tick,
_this_run: Tick,
) -> <Self as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w, '__s>( _world: UnsafeWorldCell<'__w>, state: &'__s Self::State, _last_run: Tick, _this_run: Tick, ) -> <Self as WorldQuery>::Fetch<'__w>
Creates a new instance of
Self::Fetch,
by combining data from the [World] with the cached Self::State.
Readonly accesses resources registered in [WorldQuery::update_component_access]. Read moreSourcefn update_component_access(state: &Self::State, _access: &mut FilteredAccess)
fn update_component_access(state: &Self::State, _access: &mut FilteredAccess)
Sourcefn init_nested_access(
state: &Self::State,
_system_name: Option<&str>,
_component_access_set: &mut FilteredAccessSet,
_world: UnsafeWorldCell<'_>,
)
fn init_nested_access( state: &Self::State, _system_name: Option<&str>, _component_access_set: &mut FilteredAccessSet, _world: UnsafeWorldCell<'_>, )
Adds any component accesses to other entities used by this [
WorldQuery]. Read moreSourcefn init_state(world: &mut World) -> UpdateEntityQueryState
fn init_state(world: &mut World) -> UpdateEntityQueryState
Creates and initializes a
State for this [WorldQuery] type.Sourcefn matches_component_set(
state: &Self::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &Self::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
Sourcefn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
fn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
Called when the query state is updating its archetype cache.
This can be used by nested queries to update their internal archetype caches.
impl ArchetypeQueryData for UpdateEntityQuerywhere
for<'__a> &'static EntityId: ArchetypeQueryData,
for<'__a> &'static Position: ArchetypeQueryData,
for<'__a> &'static OldPosition: ArchetypeQueryData,
for<'__a> &'static EntityLayerId: ArchetypeQueryData,
for<'__a> &'static OldEntityLayerId: ArchetypeQueryData,
for<'__a> Ref<'static, Look>: ArchetypeQueryData,
for<'__a> Ref<'static, HeadYaw>: ArchetypeQueryData,
for<'__a> &'static OnGround: ArchetypeQueryData,
for<'__a> Ref<'static, Velocity>: ArchetypeQueryData,
for<'__a> &'static TrackedData: ArchetypeQueryData,
for<'__a> &'static EntityStatuses: ArchetypeQueryData,
for<'__a> &'static EntityAnimations: ArchetypeQueryData,
for<'__a> Option<&'static TrackedEntityAttributes>: ArchetypeQueryData,
impl IterQueryData for UpdateEntityQuerywhere
for<'__a> &'static EntityId: IterQueryData,
for<'__a> &'static Position: IterQueryData,
for<'__a> &'static OldPosition: IterQueryData,
for<'__a> &'static EntityLayerId: IterQueryData,
for<'__a> &'static OldEntityLayerId: IterQueryData,
for<'__a> Ref<'static, Look>: IterQueryData,
for<'__a> Ref<'static, HeadYaw>: IterQueryData,
for<'__a> &'static OnGround: IterQueryData,
for<'__a> Ref<'static, Velocity>: IterQueryData,
for<'__a> &'static TrackedData: IterQueryData,
for<'__a> &'static EntityStatuses: IterQueryData,
for<'__a> &'static EntityAnimations: IterQueryData,
for<'__a> Option<&'static TrackedEntityAttributes>: IterQueryData,
impl ReadOnlyQueryData for UpdateEntityQuery
impl SingleEntityQueryData for UpdateEntityQuerywhere
for<'__a> &'static EntityId: SingleEntityQueryData,
for<'__a> &'static Position: SingleEntityQueryData,
for<'__a> &'static OldPosition: SingleEntityQueryData,
for<'__a> &'static EntityLayerId: SingleEntityQueryData,
for<'__a> &'static OldEntityLayerId: SingleEntityQueryData,
for<'__a> Ref<'static, Look>: SingleEntityQueryData,
for<'__a> Ref<'static, HeadYaw>: SingleEntityQueryData,
for<'__a> &'static OnGround: SingleEntityQueryData,
for<'__a> Ref<'static, Velocity>: SingleEntityQueryData,
for<'__a> &'static TrackedData: SingleEntityQueryData,
for<'__a> &'static EntityStatuses: SingleEntityQueryData,
for<'__a> &'static EntityAnimations: SingleEntityQueryData,
for<'__a> Option<&'static TrackedEntityAttributes>: SingleEntityQueryData,